![Python Build](https://github.com/unitaryfund/mitiq/workflows/Python%20Build/badge.svg?branch=master)
[![Unitary Fund](https://img.shields.io/badge/Supported%20By-UNITARY%20FUND-brightgreen.svg?style=for-the-badge)](http://unitary.fund)

# Mitiq
A Python toolkit for implementing error mitigation on quantum computers.

## Contents
```
mitiq/mitiq/
    | about
    | matrices
```
## Installation
To install locally use:
```bash
pip install -e .
```

To install for development use:
```bash
pip install -e .[development]
```
Note that this will install our testing environment.


## Documentation
`Mitiq` documentation is found under `mitiq/docs`.

## Development and Testing
Ensure that you have installed the development environment.
Then you can run tests with `pytest`.

## Authors
Ryan LaRose, Andrea Mari, Nathan Shammah, and Will Zeng.

## Support
`mitiq` development is supported by Unitary Fund.


## License
[GNU GPL v.3.0.](LICENSE)
